@@ -1,6 +1,8 @@
-from .character_class import CP1252_PRINTABLE, regex_character_class
+from .character_class import CP1252_PRINTABLE
+from .character_class import regex_character_class
 from .option_transformer import OptionTransformer
-from .swtor_case import swtor_lower, swtor_upper
+from .swtor_case import swtor_lower
+from .swtor_case import swtor_upper
 
 __all__ = [
     "CP1252_PRINTABLE",
